Context Discovery Actuator Profile
-----------------------------------

.. toctree::
   :maxdepth: 1

   1__goals_of_context_discovery
   2__data_model
   3__command_components
   4__response_components
   5__ctxd_data_types
   
